verifier

package
v0.0.0-...-ee075e7 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 3, 2026 License: Apache-2.0, Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func VerifyContainment

func VerifyContainment(data []byte, payload string) error

VerifyContainment checks if the payload string is present in the raw bytes.

func VerifyDOCX

func VerifyDOCX(data []byte, payload string) error

VerifyDOCX checks if the payload is present in the document.xml part of the DOCX.

func VerifyHTML

func VerifyHTML(data []byte, payload string) error

VerifyHTML parses the HTML to ensure validity and checks for payload presence.

func VerifyMP3

func VerifyMP3(data []byte, payload string) error

VerifyMP3 checks if the payload is present in the USLT frame.

func VerifyXLSX

func VerifyXLSX(data []byte, payload string) error

VerifyXLSX checks if the payload is present in a hidden sheet's A1 cell.

Types

type Verifier

type Verifier func(data []byte, payload string) error

Verifier defines a function that checks if a payload is correctly injected into data.

Jump to