Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func VerifyContainment ¶
VerifyContainment checks if the payload string is present in the raw bytes.
func VerifyDOCX ¶
VerifyDOCX checks if the payload is present in the document.xml part of the DOCX.
func VerifyHTML ¶
VerifyHTML parses the HTML to ensure validity and checks for payload presence.
func VerifyXLSX ¶
VerifyXLSX checks if the payload is present in a hidden sheet's A1 cell.
Types ¶
Click to show internal directories.
Click to hide internal directories.